
# Slot: length_of_longest_causal_association_path

The maximum number of hops along activities along the direction of causal flow in a model.

URI: [gocam:queryIndex__length_of_longest_causal_association_path](https://w3id.org/gocam/queryIndex__length_of_longest_causal_association_path)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)
